@@ -24,7 +24,7 @@
 	#define min(a,b)   (((a) < (b)) ? (a) : (b))
 #endif
 
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
 //===============================================================================================
 // FUNCTION: _GetRootDir
 // PURPOSE:  Extracts the root directory of a full or partial path.
@@ -65,7 +65,7 @@ static BOOL AllocReadWriteBuffer(ATF_FILEINFO *pATF, DWORD dwDesiredAccess)
    if (dwDesiredAccess == 0)
       return TRUE;
 
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
    char szRootDir[_MAX_DRIVE+2];
    if (_GetRootDir(pATF->pszFileName, szRootDir, sizeof(szRootDir)))
    {
@@ -107,7 +107,7 @@ static BOOL FreeReadWriteBuffer(ATF_FILEINFO *pATF)
 
    DWORD dwBytesWritten = 0;
    if (!pATF->bRead && pATF->lPos != 0L)
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
        WriteFile(pATF->hFile, pATF->pszBuf, pATF->lPos, &dwBytesWritten, NULL);
 #else
        c_WriteFile((FILE*)pATF->hFile, pATF->pszBuf, pATF->lPos, &dwBytesWritten, NULL);
@@ -136,7 +136,7 @@ HANDLE CreateFileBuf(ATF_FILEINFO *pATF, DWORD dwDesiredAccess, DWORD dwShareMod
                      LPSECURITY_ATTRIBUTES lpSecurityAttributes, DWORD dwCreationDisposition, 
                      DWORD dwFlagsAndAttributes, HANDLE hTemplateFile )
 {
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
       pATF->hFile = CreateFileA(pATF->pszFileName, dwDesiredAccess, dwShareMode, lpSecurityAttributes,
                             dwCreationDisposition, dwFlagsAndAttributes, hTemplateFile);
 #else
@@ -148,7 +148,7 @@ HANDLE CreateFileBuf(ATF_FILEINFO *pATF, DWORD dwDesiredAccess, DWORD dwShareMod
       // allocate buffer, initialize flags:
       if (!AllocReadWriteBuffer(pATF, dwDesiredAccess))
       {
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
          CloseHandle(pATF->hFile);         
 #else
          c_CloseHandle((FILE*)pATF->hFile);         
@@ -170,7 +170,7 @@ HANDLE CreateFileBuf(ATF_FILEINFO *pATF, DWORD dwDesiredAccess, DWORD dwShareMod
 BOOL CloseHandleBuf(ATF_FILEINFO *pATF)
 {
    BOOL bReturn = FreeReadWriteBuffer(pATF);
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
    return CloseHandle(pATF->hFile) && bReturn;
 #else
    return c_CloseHandle((FILE*)pATF->hFile) && bReturn;
@@ -200,7 +200,7 @@ BOOL WriteFileBuf(ATF_FILEINFO *pATF, LPCVOID pvBuffer, DWORD dwBytes, DWORD *pd
 
    // perform write if buffer size is 0:
    if (lBufSize == 0L)
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
        return WriteFile(pATF->hFile, pvBuffer, dwBytes, pdwWritten, lpOverlapped);
 #else
        return c_WriteFile((FILE*)pATF->hFile, pvBuffer, dwBytes, pdwWritten, lpOverlapped);
@@ -231,7 +231,7 @@ BOOL WriteFileBuf(ATF_FILEINFO *pATF, LPCVOID pvBuffer, DWORD dwBytes, DWORD *pd
 
    // write initial buffer - results handled in case 2 and 3:
    DWORD dwBytesWritten = 0;
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
    BOOL  bReturn = WriteFile(pATF->hFile, pszWriteBuf, lBufSize, &dwBytesWritten, lpOverlapped);
 #else
    BOOL  bReturn = c_WriteFile((FILE*)pATF->hFile, pszWriteBuf, lBufSize, &dwBytesWritten, lpOverlapped);
@@ -251,7 +251,7 @@ BOOL WriteFileBuf(ATF_FILEINFO *pATF, LPCVOID pvBuffer, DWORD dwBytes, DWORD *pd
    // case 3:  multiple buffer's worth (write mem buffer, write the remainder, reset internals)
    if (bReturn)
    {
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
        bReturn = WriteFile(pATF->hFile, ((BYTE *)pvBuffer + lMoveSize), 
                           dwBytes - lMoveSize, &dwBytesWritten, lpOverlapped);
 #else
@@ -288,7 +288,7 @@ BOOL ReadFileBuf(ATF_FILEINFO *pATF, LPVOID pvBuffer, DWORD dwBytes, DWORD *pdwR
 
    // perform read if buffer size is 0:
    if (pATF->lBufSize == 0L)
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
       return ReadFile(pATF->hFile, pvBuffer, dwBytes, pdwRead, lpOverlapped);
 #else
       return c_ReadFile((FILE*)pATF->hFile, pvBuffer, dwBytes, pdwRead, lpOverlapped);
@@ -301,7 +301,7 @@ BOOL ReadFileBuf(ATF_FILEINFO *pATF, LPVOID pvBuffer, DWORD dwBytes, DWORD *pdwR
 
       // commit current cache:
       if (pATF->lPos > 0L)
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
          if (!WriteFile(pATF->hFile, pATF->pszBuf, pATF->lPos, &dwBytesWritten, NULL))
 #else
          if (!c_WriteFile((FILE*)pATF->hFile, pATF->pszBuf, pATF->lPos, &dwBytesWritten, NULL))
@@ -342,7 +342,7 @@ BOOL ReadFileBuf(ATF_FILEINFO *pATF, LPVOID pvBuffer, DWORD dwBytes, DWORD *pdwR
    //         (perform a full read; leaves buffer empty)
    if (dwBytes - (DWORD)lMoveSize >= (DWORD)pATF->lBufReadLimit)
    {
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
        bReturn = ReadFile(pATF->hFile, ((BYTE *)pvBuffer + lMoveSize), 
                          dwBytes - lMoveSize, &dwBytesRead, lpOverlapped);
 #else
@@ -359,7 +359,7 @@ BOOL ReadFileBuf(ATF_FILEINFO *pATF, LPVOID pvBuffer, DWORD dwBytes, DWORD *pdwR
 
    // case 3: request runs past end of buffer, and wants less than another buffer's worth:
    //        (read in another buffer, copy wanted portion, advance lPos)
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
    bReturn = ReadFile(pATF->hFile, pszReadBuf, lBufSize, &dwBytesRead, lpOverlapped);
 #else
    bReturn = c_ReadFile((FILE*)pATF->hFile, pszReadBuf, lBufSize, &dwBytesRead, lpOverlapped);
@@ -405,7 +405,7 @@ DWORD SetFilePointerBuf(ATF_FILEINFO *pATF, long lToMove, PLONG plDistHigh, DWOR
    // move real file position to lPos:
    if (pATF->bRead) 
    {
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
       if (SetFilePointer(pATF->hFile, pATF->lPos - pATF->lBufReadLimit, NULL, FILE_CURRENT) == 0xFFFFFFFF)
 #else
       if (c_SetFilePointer((FILE*)pATF->hFile, pATF->lPos - pATF->lBufReadLimit, NULL, FILE_CURRENT) == 0xFFFFFFFF)
@@ -417,7 +417,7 @@ DWORD SetFilePointerBuf(ATF_FILEINFO *pATF, long lToMove, PLONG plDistHigh, DWOR
    {
       if (pATF->lPos != 0L)
       {
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
           if (!WriteFile(pATF->hFile, pATF->pszBuf, pATF->lPos, &dwBytesWritten, NULL))
 #else
           if (!c_WriteFile((FILE*)pATF->hFile, pATF->pszBuf, pATF->lPos, &dwBytesWritten, NULL))
@@ -429,7 +429,7 @@ DWORD SetFilePointerBuf(ATF_FILEINFO *pATF, long lToMove, PLONG plDistHigh, DWOR
    pATF->bRead          = TRUE;
    pATF->lPos           = pATF->lBufSize;
    pATF->lBufReadLimit  = pATF->lBufSize;
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
    return SetFilePointer(pATF->hFile, lToMove, plDistHigh, dwMoveMethod);
 #else
    return c_SetFilePointer((FILE*)pATF->hFile, lToMove, plDistHigh, dwMoveMethod);
@@ -547,7 +547,7 @@ int getsBuf(ATF_FILEINFO *pATF, LPSTR pszString, DWORD dwBufSize)
 
       // commit current cache:
       if (pATF->lPos > 0)
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
           if (!WriteFile(pATF->hFile, pATF->pszBuf, pATF->lPos, &dwBytesWritten, NULL))
 #else
           if (!c_WriteFile((FILE*)pATF->hFile, pATF->pszBuf, pATF->lPos, &dwBytesWritten, NULL))
@@ -608,7 +608,7 @@ int getsBuf(ATF_FILEINFO *pATF, LPSTR pszString, DWORD dwBufSize)
          if (dwToRead > 0)    // ie - we arrived here because lBytesInBuf == 0
          {
             DWORD dwBytesRead;
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
             if (!ReadFile(pATF->hFile, pszReadBuf, pATF->lBufSize, &dwBytesRead, NULL))
 #else
             if (!c_ReadFile((FILE*)pATF->hFile, pszReadBuf, pATF->lBufSize, &dwBytesRead, NULL))
@@ -665,7 +665,7 @@ int putsBuf(ATF_FILEINFO *pATF, LPCSTR pszString)
 
    // perform write if buffer size is 0:
    if (pATF->lBufSize == 0L)
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
        return WriteFile(pATF->hFile, pszString, dwBytes, &dwBytesWritten, NULL);
 #else
        return c_WriteFile((FILE*)pATF->hFile, pszString, dwBytes, &dwBytesWritten, NULL);
@@ -694,7 +694,7 @@ int putsBuf(ATF_FILEINFO *pATF, LPCSTR pszString)
       return TRUE;
 
    // write initial buffer - results handled in case 2 and 3:
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
    BOOL bReturn = WriteFile(pATF->hFile, pszWriteBuf, lBufSize, &dwBytesWritten, NULL);
 #else
    BOOL bReturn = c_WriteFile((FILE*)pATF->hFile, pszWriteBuf, lBufSize, &dwBytesWritten, NULL);
@@ -711,7 +711,7 @@ int putsBuf(ATF_FILEINFO *pATF, LPCSTR pszString)
 
    // case 3:  multiple buffer's worth (write mem buffer, write the remainder, reset internals)
    if (bReturn)
-#if defined(_WINDOWS)
+#if defined(_MSC_VER)
        bReturn = WriteFile(pATF->hFile, pszString + lMoveSize, 
                           dwBytes - lMoveSize, &dwBytesWritten, NULL);
 #else
