@@ -159,16 +159,19 @@ enum filetype {
     hdf5,   /*!< hdf5 files. */
     heka,   /*!< heka files. */
     biosig, /*!< biosig files. */
+    tdms,   /*!< TDMS files. */
     none    /*!< Undefined file type. */
 };
 
   
+#ifndef TEST_MINIMAL
 //! Attempts to determine the filetype from the filter extension.
 /*! \param ext The filter extension to be tested (in the form wxT("*.ext")).
  *  \return The corresponding file type.
  */
 StfioDll stfio::filetype
 findType(const std::string& ext);
+#endif // TEST_MINIMAL
 
 //! Returns file extension for a file type
 /*! \param ftype File type
