@@ -170,7 +170,11 @@ bool wxStfApp::OnInit(void)
 #endif
 #if (defined(WITH_BIOSIG) || defined(WITH_BIOSIG2))
     m_biosigTemplate=new wxDocTemplate( docManager,
+#   if (BIOSIG_VERSION < 10800)
                                      wxT("Biosig files"), wxT("*.dat;*.cfs;*.gdf;*.ibw"), wxT(""), wxT(""),
+#   else
+                                     wxT("Biosig files"), wxT("*.dat;*.cfs;*.gdf;*.ibw;*.wcp"), wxT(""), wxT(""),
+#   endif
                                      wxT("Biosig Document"), wxT("Biosig View"), CLASSINFO(wxStfDoc),
                                      CLASSINFO(wxStfView) );
 #endif
@@ -449,8 +453,8 @@ void wxStfApp::OnPeakcalcexecMsg(wxStfDoc* actDoc) {
 
          case stf::latency_cursor:
              // Use peak cursors for latency?
-             actDoc->SetLatencyWindowMode(CursorsDialog->UsePeak4Latency() );
-             wxWriteProfileInt(wxT("Settings"), wxT("LatencyWindowMode"), CursorsDialog->UsePeak4Latency() );
+             // actDoc->SetLatencyWindowMode(CursorsDialog->UsePeak4Latency() );
+             // wxWriteProfileInt(wxT("Settings"), wxT("LatencyWindowMode"), CursorsDialog->UsePeak4Latency() );
 
              // Latency start mode
              actDoc->SetLatencyBeg(CursorsDialog->GetCursor1L());
